==> angelscript_2.27.0.zip: sdk/docs/manual/doc_script.js <==
var doc_script =
[
    [ "Global entities", "doc_script_global.html", "doc_script_global" ],
    [ "Statements", "doc_script_statements.html", [
      [ "Variable declarations", "doc_script_statements.html#variable", null ],
      [ "Expression statement", "doc_script_statements.html#expression", null ],
      [ "Conditions: if / if-else / switch-case", "doc_script_statements.html#if", null ],
      [ "Loops: while / do-while / for", "doc_script_statements.html#while", null ],
      [ "Loop control: break / continue", "doc_script_statements.html#break", null ],
      [ "Return statement", "doc_script_statements.html#return", null ],
      [ "Statement blocks", "doc_script_statements.html#block", null ]
    ] ],
    [ "Expressions", "doc_expressions.html", [
      [ "Assignments", "doc_expressions.html#assignment", null ],
      [ "Compound assignments", "doc_expressions.html#compound", null ],
      [ "Function call", "doc_expressions.html#function", null ],
      [ "Type conversions", "doc_expressions.html#conversion", null ],
      [ "Math operators", "doc_expressions.html#math", null ],
      [ "Bitwise operators", "doc_expressions.html#bits", null ],
      [ "Logic operators", "doc_expressions.html#logic", null ],
      [ "Equality comparison operators", "doc_expressions.html#equal", null ],
      [ "Relational comparison operators", "doc_expressions.html#relation", null ],
      [ "Identity comparison operators", "doc_expressions.html#identity", null ],
      [ "Increment operators", "doc_expressions.html#increment", null ],
      [ "Indexing operator", "doc_expressions.html#opindex", null ],
      [ "Conditional expression", "doc_expressions.html#condition", null ],
      [ "Member access", "doc_expressions.html#member", null ],
      [ "Handle-of", "doc_expressions.html#handle", null ],
      [ "Parenthesis", "doc_expressions.html#parenthesis", null ],
      [ "Scope resolution", "doc_expressions.html#scope", null ]
    ] ],
    [ "Data types", "doc_datatypes.html", "doc_datatypes" ],
    [ "Object handles", "doc_script_handle.html", [
      [ "General usage", "doc_script_handle.html#doc_script_handle_1", null ],
      [ "Object life times", "doc_script_handle.html#doc_script_handle_2", null ],
      [ "Object relations and polymorphing", "doc_script_handle.html#doc_script_handle_3", null ]
    ] ],
    [ "Shared script entities", "doc_script_shared.html", [
      [ "How to declare shared entities", "doc_script_shared.html#doc_script_shared_1", null ],
      [ "What can be shared", "doc_script_shared.html#doc_script_shared_2", null ]
    ] ],
    [ "Operator precedence", "doc_operator_precedence.html", [
      [ "Unary operators", "doc_operator_precedence.html#unary", null ],
      [ "Binary and ternary operators", "doc_operator_precedence.html#binary", null ]
    ] ],
    [ "Reserved keywords and tokens", "doc_reserved_keywords.html", null ]
];

==> angelscript_2.31.2.zip: sdk/docs/manual/doc_script.js <==
var doc_script =
[
    [ "Global entities", "doc_script_global.html", "doc_script_global" ],
    [ "Statements", "doc_script_statements.html", [
      [ "Variable declarations", "doc_script_statements.html#variable", null ],
      [ "Expression statement", "doc_script_statements.html#expression", null ],
      [ "Conditions: if / if-else / switch-case", "doc_script_statements.html#if", null ],
      [ "Loops: while / do-while / for", "doc_script_statements.html#while", null ],
      [ "Loop control: break / continue", "doc_script_statements.html#break", null ],
      [ "Return statement", "doc_script_statements.html#return", null ],
      [ "Statement blocks", "doc_script_statements.html#block", null ]
    ] ],
    [ "Expressions", "doc_expressions.html", [
      [ "Assignments", "doc_expressions.html#assignment", null ],
      [ "Function call", "doc_expressions.html#function", null ],
      [ "Math operators", "doc_expressions.html#math", null ],
      [ "Bitwise operators", "doc_expressions.html#bits", null ],
      [ "Compound assignments", "doc_expressions.html#compound", null ],
      [ "Logic operators", "doc_expressions.html#logic", null ],
      [ "Equality comparison operators", "doc_expressions.html#equal", null ],
      [ "Relational comparison operators", "doc_expressions.html#relation", null ],
      [ "Identity comparison operators", "doc_expressions.html#identity", null ],
      [ "Increment operators", "doc_expressions.html#increment", null ],
      [ "Indexing operator", "doc_expressions.html#opindex", null ],
      [ "Conditional expression", "doc_expressions.html#condition", null ],
      [ "Member access", "doc_expressions.html#member", null ],
      [ "Handle-of", "doc_expressions.html#handle", null ],
      [ "Parenthesis", "doc_expressions.html#parenthesis", null ],
      [ "Scope resolution", "doc_expressions.html#scope", null ],
      [ "Type conversions", "doc_expressions.html#conversion", null ],
      [ "Anonymous objects", "doc_expressions.html#anonobj", null ]
    ] ],
    [ "Data types", "doc_datatypes.html", "doc_datatypes" ],
    [ "Functions", "doc_script_func.html", "doc_script_func" ],
    [ "Script classes", "doc_script_class.html", "doc_script_class" ],
    [ "Object handles", "doc_script_handle.html", [
      [ "General usage", "doc_script_handle.html#doc_script_handle_1", null ],
      [ "Object life times", "doc_script_handle.html#doc_script_handle_2", null ],
      [ "Object relations and polymorphing", "doc_script_handle.html#doc_script_handle_3", null ]
    ] ],
    [ "Shared script entities", "doc_script_shared.html", [
      [ "How to declare shared entities", "doc_script_shared.html#doc_script_shared_1", null ],
      [ "What can be shared", "doc_script_shared.html#doc_script_shared_2", null ]
    ] ],
    [ "Operator precedence", "doc_operator_precedence.html", [
      [ "Unary operators", "doc_operator_precedence.html#unary", null ],
      [ "Binary and ternary operators", "doc_operator_precedence.html#binary", null ]
    ] ],
    [ "Reserved keywords and tokens", "doc_reserved_keywords.html", null ]
];
